pub struct AgentGroup { /* private fields */ }Expand description
A group of agents that can be executed together.
Implementations
Sourceimpl AgentGroup
impl AgentGroup
Sourcepub fn new(strategy: GroupStrategy) -> Self
pub fn new(strategy: GroupStrategy) -> Self
Create a new empty group with the given strategy.
Sourcepub async fn run(&self, prompt: String) -> SdkResult<GroupResult>
pub async fn run(&self, prompt: String) -> SdkResult<GroupResult>
Execute the group with the given prompt.