pub enum Mode {
Default,
Auto,
}Expand description
Stable since 0.63.0
Agent autonomy mode.
Mode::Default: normal interactive behavior — the agent may use theasktool to request user input.Mode::Auto: autonomous operation — the agent runs to completion without asking the user questions. Theasktool is short-circuited.
Variants
Default
Normal interactive behavior (the default).
Auto
Autonomous operation — no user questions, run to completion.
Implementations