TodoOp

Enum TodoOp 

pub enum TodoOp {
    Init {
        list: Option<Vec<InitListEntry>>,
        items: Option<Vec<String>>,
    },
    Start {
        task: Option<String>,
        phase: Option<String>,
    },
    Done {
        task: Option<String>,
        phase: Option<String>,
    },
    Drop {
        task: Option<String>,
        phase: Option<String>,
    },
    Rm {
        task: Option<String>,
        phase: Option<String>,
    },
    Append {
        phase: String,
        items: Vec<String>,
    },
    Block {
        task: Option<String>,
        phase: Option<String>,
        reason: Option<String>,
    },
    Unblock {
        task: Option<String>,
        phase: Option<String>,
    },
    View,
}
Stable since 0.63.0
Operations that can be applied to a todo list.

Variants



Init

Initialize or replace the todo list.

Fields

list: Option<Vec<InitListEntry>>

Optional structured phase definitions.

items: Option<Vec<String>>

Optional flat list of task contents.



Start

Mark matching tasks as in progress.

Fields

task: Option<String>

Task content filter.

phase: Option<String>

Phase name filter.



Done

Mark matching tasks as completed.

Fields

task: Option<String>

Task content filter.

phase: Option<String>

Phase name filter.



Drop

Mark matching tasks as abandoned.

Fields

task: Option<String>

Task content filter.

phase: Option<String>

Phase name filter.



Rm

Remove matching tasks entirely.

Fields

task: Option<String>

Task content filter.

phase: Option<String>

Phase name filter.



Append

Append tasks to a phase, creating it if it does not exist.

Fields

phase: String

Name of the target phase.

items: Vec<String>

Task contents to append.



Block

Mark matching tasks as blocked (waiting on external input). Terminal states (Completed/Abandoned) are left untouched.

Fields

task: Option<String>

Task content filter.

phase: Option<String>

Phase name filter.

reason: Option<String>

Optional human-readable reason the task is blocked.



Unblock

Return matching blocked tasks to pending.

Fields

task: Option<String>

Task content filter.

phase: Option<String>

Phase name filter.



View

Return the current state without modifying it.