pub struct AgentPool { /* private fields */ }Expand description
Pool of live Agent instances keyed by string ID.
Thread-safe via parking_lot::RwLock. Agents can be inserted,
retrieved, removed, and have their state exported/imported.
Implementations
Sourceimpl AgentPool
impl AgentPool
Sourcepub fn export_state(&self, id: &str) -> Option<Value>
pub fn export_state(&self, id: &str) -> Option<Value>
Export an agent’s state as JSON.
Returns None if the agent is not in the pool or state
serialization fails.
Sourcepub fn import_state(&self, id: &str, state: Value) -> bool
pub fn import_state(&self, id: &str, state: Value) -> bool
Import agent state from JSON.
Returns false if the agent is not in the pool or import fails.