CapabilityResolver

Trait CapabilityResolver 

pub trait CapabilityResolver:
    Send
    + Sync
    + 'static {
    // Required method
    fn visible_tools(
        &self,
        subject: &str,
    ) -> Pin<Box<dyn Future<Output = Result<Vec<String>, SdkError>> + Send + '_>>;
}
Resolves the set of tools visible to a given subject.

Required Methods

fn visible_tools( &self, subject: &str, ) -> Pin<Box<dyn Future<Output = Result<Vec<String>, SdkError>> + Send + '_>>

Returns the set of tool names visible to subject.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors