ResourceMonitor

Trait ResourceMonitor 

pub trait ResourceMonitor:
    Send
    + Sync
    + 'static {
    // Required method
    fn snapshot(
        &self,
    ) -> Pin<Box<dyn Future<Output = Result<ResourceUsage, SdkError>> + Send + '_>>;

    // Provided method
    fn is_over_budget(
        &self,
    ) -> Pin<Box<dyn Future<Output = Result<bool, SdkError>> + Send + '_>> { ... }
}
Reports current resource usage and whether the budget is exceeded.

Required Methods

fn snapshot( &self, ) -> Pin<Box<dyn Future<Output = Result<ResourceUsage, SdkError>> + Send + '_>>

Snapshot the current usage.

Provided Methods

fn is_over_budget( &self, ) -> Pin<Box<dyn Future<Output = Result<bool, SdkError>> + Send + '_>>

Returns true if the current usage exceeds the configured budget.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors