pub struct SearchCache { /* private fields */ }Expand description
Stable since 0.63.0
In-memory cache for search results, keyed by search ID.Implementations
Sourceimpl SearchCache
impl SearchCache
Sourcepub fn new() -> SearchCache
pub fn new() -> SearchCache
Create a new empty cache with default capacity (64 entries).
Sourcepub fn with_capacity(max_entries: usize) -> SearchCache
pub fn with_capacity(max_entries: usize) -> SearchCache
Create a new cache with the given maximum capacity.