load_overrides

Function load_overrides 

pub fn load_overrides() -> Option<OverrideFile>
Stable since 0.63.0
Apply a list of override files to a catalog snapshot.

Returns a new OverrideFile that is the union of all overrides. In a real merge step the caller would apply this to the built-in BuiltinProviderEntry and BuiltinModelEntry lists.

Returns None if no override files were found, or all failed to parse.