pub struct AgentAdvisor { /* private fields */ }Expand description
Unstable (feature: advisor) — may change or be removed
An [`AdvisorAgent`] backed by a concrete [`Agent`].Implementations
Sourceimpl AgentAdvisor
impl AgentAdvisor
Sourcepub fn new(agent: Arc<Agent>) -> AgentAdvisor
pub fn new(agent: Arc<Agent>) -> AgentAdvisor
Wrap an Agent as an advisor-driving AdvisorAgent.
Sourcepub fn with_post_prompt_hook(
agent: Arc<Agent>,
hook: Arc<dyn Fn(&Agent) + Send + Sync>,
) -> AgentAdvisor
pub fn with_post_prompt_hook( agent: Arc<Agent>, hook: Arc<dyn Fn(&Agent) + Send + Sync>, ) -> AgentAdvisor
Wrap an Agent with a hook fired after each successful advisor prompt.
Used by the host to persist advisor turns to <session>/__advisor.jsonl
for stats attribution / observability.
Sourcepub fn agent(&self) -> &Agent
pub fn agent(&self) -> &Agent
Access the underlying agent (for transcript-recorder / event wiring).
Sourcepub fn into_agent(self) -> Arc<Agent> ⓘ
pub fn into_agent(self) -> Arc<Agent> ⓘ
Clone the underlying agent handle (cheap — Arc clone).